<?php

namespace Drupal\image_deriver\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\Core\Entity\EntityWithPluginCollectionInterface;
use Drupal\Core\Plugin\DefaultLazyPluginCollection;

/**
 * Defines the Deriver entity.
 *
 * @ConfigEntityType(
 *   id = "image_deriver",
 *   label = @Translation("Image Deriver"),
 *   handlers = {
 *     "list_builder" = "Drupal\image_deriver\DeriverListBuilder",
 *     "form" = {
 *       "add" = "Drupal\image_deriver\Form\DeriverAddForm",
 *       "edit" = "Drupal\image_deriver\Form\DeriverEditForm",
 *       "delete" = "Drupal\image_deriver\Form\DeriverDeleteForm"
 *     }
 *   },
 *   config_prefix = "image_deriver",
 *   admin_permission = "administer image deriver",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label"
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "single_image_deriver",
 *     "derivers"
 *   },
 *   links = {
 *     "canonical" = "/admin/config/media/image-deriver/{image_deriver}",
 *     "add-form" = "/admin/config/media/image-deriver/add",
 *     "edit-form" = "/admin/config/media/image-deriver/{image_deriver}/edit",
 *     "delete-form" = "/admin/config/media/image-deriver/{image_deriver}/delete",
 *     "collection" = "/admin/config/media/image-deriver"
 *   }
 * )
 */
class ImageDeriver extends ConfigEntityBase implements EntityWithPluginCollectionInterface {
  /**
   * The ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The label.
   *
   * @var string
   */
  protected $label;


  /**
   * The list of processors attached to the deriver.
   *
   * @var array
   */
  protected $derivers = [];

  /**
   * The single image deriver.
   *
   * @var string
   */
  protected $single_image_deriver;


  /**
   * {@inheritdoc}
   */
  public function id() {
    return $this->id;
  }

  /**
   * @param $plugin_id
   * @param array $configuration
   *
   * @return void
   */
  public function addDeriver(string $plugin_id, array $configuration = []) {
    $this->derivers[$plugin_id] = $configuration;
  }

  public function setDerivers(array $derivers) {
    $this->derivers = $derivers;
  }

  public function removeDeriver(string $plugin_id) {
    unset($this->derivers[$plugin_id]);
  }

  public function getDeriver(string $plugin_id) {
    return $this->derivers[$plugin_id] ?? NULL;
  }

  public function getDerivers() {
    return $this->derivers;
  }

  public function setSingleImageDeriver(string $plugin_id) {
    $this->single_image_deriver = $plugin_id;
  }

  public function getSingleImageDeriver() {
    return $this->single_image_deriver;
  }

  public function updateDeriver(string $plugin_id, array $configuration = []) {
    $this->derivers[$plugin_id] = $configuration;
  }

  public function getPluginCollection() {
    return new DefaultLazyPluginCollection(\Drupal::service('image_deriver.plugin_manager'), $this->getDerivers());
  }

  public function getPluginCollections() {
    return ['derivers' => $this->getPluginCollection()];
  }

  public function getSortedDerivers() {
    $derivers = $this->getPluginCollection();
    $derivers = $derivers->getConfiguration();
    uasort($derivers, function($a, $b) {
      return $a['weight'] <=> $b['weight'];
    });
    return $derivers;
  }

  public static function getDeriverById($id) {
    // if id is "site_default", then load up the configuration and get the site default
    if ($id === 'site_default') {
      $config = \Drupal::config('image_deriver.settings');
      $id = $config->get('default_deriver_entity') ?? FALSE;
    }
    if ($id && $id !== 'none') {
      return self::load($id);
    }

    return NULL;
  }
}
