<?php

namespace Drupal\image_deriver\Entity;

use Drupal\image\ImageEffectPluginCollection;

trait ImageStyleDerivativeHandlerTrait {

  /**
   * Checks if the derivative requires a deriver.
   *
   * This is a helper function to determine if the derivative requires a deriver.
   *
   * @param $original_uri
   *   The original URI.
   * @param $derivative_uri
   *   The derivative URI.
   * @return bool
   */
  protected function requiresDeriver($original_uri, $derivative_uri) {
    $original_file_type = pathinfo($original_uri, PATHINFO_EXTENSION);
    $derivative_file_type = pathinfo($derivative_uri, PATHINFO_EXTENSION);
    // Check if file type is changing, and check if already changed by existing style.
    return $original_file_type !== $derivative_file_type && $this->getDerivativeExtension($original_file_type) !== $derivative_file_type;
  }

  /**
   * Load the image deriver plugin.
   *
   * @param $derivative_uri
   *  The derivative URI.
   *
   * @return mixed
   */
  protected function getImageDeriverPlugin($derivative_uri) {
    // @todo Replace with better handling of file name variations.
    return \Drupal::service('image_deriver.plugin_manager')->createInstance(pathinfo($derivative_uri, PATHINFO_EXTENSION));
  }
}
