<?php

namespace Drupal\image_deriver\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\image_deriver\Entity\ImageDeriver;

/**
 *
 */
class DefaultImageDeriverEntityConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'image_deriver_default_entity_config';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['image_deriver.settings'];

  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, Request $request = NULL) {
    $config = $this->config('image_deriver.settings');

    // add style to the form.
    $form['#attributes']['style'] = "margin-block-start: var(--gin-spacing-l);";

    // need to get all the deriver entities.
    $deriver_entities = ImageDeriver::loadMultiple();

    // build the options array.
    $options = ['none' => $this->t('None')];
    foreach ($deriver_entities as $deriver_entity) {
      $options[$deriver_entity->id()] = $deriver_entity->label();
    }


    $form['default_deriver_entity'] = [
      '#type' => 'select',
      '#title' => $this->t('Sitewide default image deriver entity'),
      '#description' => $this->t("Select a default image deriver entity. This will affect all images unless changed at the image display formatter."),
      '#options' => $options,
      '#default_value' => $config->get('default_deriver_entity'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $this->config('image_deriver.settings')
      ->set('default_deriver_entity', $values['default_deriver_entity'])
      ->save();
  }

}
